define('dummy/tests/unit/sync-for-each-test', ['ember', 'ember-cli-sync-for-each', 'ember-qunit', 'qunit'], function (Ember, syncForEach, ember_qunit, qunit) {

  'use strict';

  var array;

  qunit.module("sync-for-each", {
    beforeEach: function () {
      array = [1, 2, 3];
    }
  });

  ember_qunit.test("it returns a promise which resolves", function (assert) {
    assert.expect(1);

    syncForEach['default'](array, function () {
      return Ember['default'].RSVP.Promise.resolve();
    }).then(function () {
      assert.ok(true);
    });
  });

  ember_qunit.test("it returns a promise which resolves, given a synchronous callback", function (assert) {
    assert.expect(1);

    syncForEach['default'](array, function () {
      return;
    }).then(function () {
      assert.ok(true);
    });
  });

  ember_qunit.test("it returns a promise which rejects if one call rejects", function (assert) {
    assert.expect(1);

    syncForEach['default'](array, function () {
      return Ember['default'].RSVP.Promise.reject();
    }).then(null, function () {
      assert.ok(true);
    });
  });

  ember_qunit.test("it returns a promise which resolves, given an empty array", function (assert) {
    assert.expect(1);

    syncForEach['default']([], function () {
      return Ember['default'].RSVP.Promise.resolve();
    }).then(function () {
      assert.ok(true);
    });
  });

  ember_qunit.test("it works with array", function (assert) {
    assert.expect(2);

    var testArray = [];

    syncForEach['default'](array, function (item) {
      testArray.push(item);
      return Ember['default'].RSVP.Promise.resolve();
    }).then(function (result) {
      assert.equal(result, array, "returns the input array");
      assert.deepEqual(testArray, array, "executes in correct order");
    });
  });

  ember_qunit.test("it works with DS.ManyArray", function (assert) {
    assert.expect(2);

    var manyArray = DS.ManyArray.create({ content: array });
    var testArray = [];

    syncForEach['default'](manyArray, function (item) {
      testArray.push(item);
      return Ember['default'].RSVP.Promise.resolve();
    }).then(function (result) {
      assert.equal(result, manyArray, "returns the input array");
      assert.deepEqual(testArray, array, "executes in correct order");
    });
  });

  ember_qunit.test("it rejects with the rejection reason", function (assert) {
    assert.expect(1);
    var msg = "foo";

    syncForEach['default'](array, function () {
      return Ember['default'].RSVP.Promise.reject(msg);
    }).then(null, function (result) {
      assert.equal(result, msg);
    });
  });

  ember_qunit.test("it executes callback on each item", function (assert) {
    assert.expect(array.length);

    syncForEach['default'](array, function () {
      return new Ember['default'].RSVP.Promise(function (resolve) {
        assert.ok(true);
        resolve();
      });
    });
  });

  ember_qunit.test("it stops execution after rejection", function (assert) {
    assert.expect(3);

    syncForEach['default']([1, 2, 3, 4, 5], function (item) {
      return new Ember['default'].RSVP.Promise(function (resolve, reject) {
        assert.ok(true);
        if (item === 3) {
          reject();
        }
        resolve();
      });
    });
  });

  ember_qunit.test("it continues execution after rejection, when force is set", function (assert) {
    assert.expect(5);

    syncForEach['default']([1, 2, 3, 4, 5], function (item) {
      return new Ember['default'].RSVP.Promise(function (resolve, reject) {
        assert.ok(true);
        if (item === 3) {
          reject();
        }
        resolve();
      });
    }, true);
  });

  ember_qunit.test("it rejects with the rejection reason, when force is set", function (assert) {
    assert.expect(1);
    var msg = "foo";

    syncForEach['default'](array, function () {
      return Ember['default'].RSVP.Promise.reject(msg);
    }, true).then(null, function (reason) {
      assert.equal(reason, msg);
    });
  });

  ember_qunit.test("it makes index, and input array available in callback", function (assert) {
    assert.expect(3);

    syncForEach['default'](array, function (item, index, array) {
      return new Ember['default'].RSVP.Promise(function (resolve) {
        assert.equal(item, array[index]);
        resolve();
      });
    });
  });

  ember_qunit.test("it works for ember instances", function (assert) {
    assert.expect(1);

    array = ["foo", "bar", "baz"].map(function (name) {
      return Ember['default'].Object.create({
        name: name,
        rename: function (name) {
          var _this = this;
          return new Ember['default'].RSVP.Promise(function (resolve) {
            _this.set("name", name);
          });
        }
      });
    });

    syncForEach['default'](array, function (item) {
      item.rename("bar");
    }).then(function (result) {
      assert.deepEqual(result.mapBy("name"), ["bar", "bar", "bar"]);
    });
  });

});